pub const fn count_to_shadow(count: usize) -> usizeExpand description
Converts the number of bytes into the lower bound number of bytes in the shadow map.
pub const fn count_to_shadow(count: usize) -> usizeConverts the number of bytes into the lower bound number of bytes in the shadow map.