pub fn mem_to_shadow(address: VirtualAddress) -> VirtualAddressExpand description
Converts the passed address into the corresponding address in the shadow map.
pub fn mem_to_shadow(address: VirtualAddress) -> VirtualAddressConverts the passed address into the corresponding address in the shadow map.