set_shadow_free

Function set_shadow_free 

#[unsafe(export_name = "__asan_set_shadow_00")]
pub unsafe extern "C-unwind" fn set_shadow_free( address: VirtualAddress, count: usize, )
Available on crate feature full only.
Marks count entries in the shadow map starting at address as “accessible”

Safety

address must be an address in the shadow map