set_shadow_free_vmem

Function set_shadow_free_vmem 

pub unsafe extern "C-unwind" fn set_shadow_free_vmem(
    address: VirtualAddress,
    count: usize,
)
Available on crate feature full only.
Marks count entries in the shadow map starting at address as “freed virtual memory”

Safety

address must be an address in the shadow map