set_shadow_heap_free

Function set_shadow_heap_free 

#[unsafe(export_name = "__asan_set_shadow_fd")]
pub unsafe extern "C-unwind" fn set_shadow_heap_free( address: VirtualAddress, count: usize, )
Available on crate feature full only.
Marks count entries in the shadow map starting at address as “freed heap memory”

Safety

address must be an address in the shadow map