pub unsafe extern "C-unwind" fn set_shadow_uninit_vmem(
address: VirtualAddress,
count: usize,
)Available on crate feature
full only.Expand description
Marks count entries in the shadow map starting at address as “uninitialized virtual memory”
This is the default value for lazily allocated shadow memory
Safety
address must be an address in the shadow map