set_shadow_use_after_scope

Function set_shadow_use_after_scope 

#[unsafe(export_name = "__asan_set_shadow_f8")]
pub unsafe extern "C-unwind" fn set_shadow_use_after_scope( address: VirtualAddress, count: usize, )
Available on crate feature full only.
Marks count entries in the shadow map starting at address as “stack use after scope”

Safety

address must be an address in the shadow map