#[unsafe(export_name = "__asan_set_shadow_f1")]pub unsafe extern "C-unwind" fn set_shadow_stack_left(
address: VirtualAddress,
count: usize,
)Available on crate feature
full only.Expand description
Marks count entries in the shadow map starting at address as “stack left redzone”
Safety
address must be an address in the shadow map